from django.test import TestCase

from django.contrib.auth.models import User

from account.models import SignupCode

from pinax.invitations.models import JoinInvitation


class TestsJoinInvitation(TestCase):

    def setUp(self):
        self.to_user = User.objects.create(username='foo1')
        self.from_user = User.objects.create(username='foo2')
        self.signup_code = SignupCode.create(email="me@you.com")
        self.signup_code.save()
        self.status = JoinInvitation.STATUS_ACCEPTED
        self.invitation = JoinInvitation.objects.create(
            from_user=self.from_user,
            status=self.status,
            signup_code=self.signup_code,
        )

    def test_to_user_email(self):
        self.assertEqual(self.signup_code.email, "me@you.com")

    def test_accept(self):
        self.invitation.accept(self.to_user)
        self.assertEqual(self.from_user.invitationstat.invites_accepted, 1)

    def test_process_independent_joins(self):
        JoinInvitation.process_independent_joins(self.to_user, "me@you.com")
        invite = JoinInvitation.objects.get(pk=self.invitation.pk)
        self.assertEqual(invite.status, JoinInvitation.STATUS_JOINED_INDEPENDENTLY)



from django.conf.urls import url

from .views import (
    addto_all,
    addto_user,
    invite,
    topoff_all,
    invite_stat,
    topoff_user
)


urlpatterns = [
    url(r"^invite/$", invite, name="pinax-invitations-invite"),
    url(r"^invite-stat/(?P<pk>\d+)/$", invite_stat, name="pinax-invitations-invite_stat"),
    url(r"^topoff/$", topoff_all, name="pinax-invitations-topoff_all"),
    url(r"^topoff/(?P<pk>\d+)/$", topoff_user, name="pinax-invitations-topoff_user"),
    url(r"^addto/$", addto_all, name="pinax-invitations-addto_all"),
    url(r"^addto/(?P<pk>\d+)/$", addto_user, name="pinax-invitations-addto_user"),
]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.utils.timezone
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='InvitationStat',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('invites_sent', models.IntegerField(default=0)),
                ('invites_allocated', models.IntegerField(default=0)),
                ('invites_accepted', models.IntegerField(default=0)),
                ('user', models.OneToOneField(to=settings.AUTH_USER_MODEL)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='JoinInvitation',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('message', models.TextField(null=True)),
                ('sent', models.DateTimeField(default=django.utils.timezone.now)),
                ('status', models.IntegerField(choices=[(1, b'Sent'), (2, b'Accepted'), (3, b'Joined Independently')])),
                ('from_user', models.ForeignKey(related_name='invites_sent', to=settings.AUTH_USER_MODEL)),
                ('signup_code', models.OneToOneField(to='account.SignupCode')),
                ('to_user', models.ForeignKey(related_name='invites_received', to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
            },
            bases=(models.Model,),
        ),
    ]



from __future__ import unicode_literals

from django.conf import settings  # noqa

from appconf import AppConf


class PinaxInvitationsAppConf(AppConf):

    DEFAULT_EXPIRATION = 168
    DEFAULT_INVITE_ALLOCATION = 0

    class Meta:
        prefix = "pinax_invitations"
